package org.hso.ecommerce.controller.intern;

import java.util.ArrayList;
import java.util.List;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.hso.ecommerce.entities.shop.Article;
import org.hso.ecommerce.repos.shop.ArticleRepository;
import org.hso.ecommerce.repos.warehouse.WarehouseBookingPositionSlotEntryRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.view.RedirectView;

@Controller
@RequestMapping("intern/articles")
public class InternArticleController {
	@Autowired
	private final ArticleRepository articleRepository = null;

	@Autowired
	private final WarehouseBookingPositionSlotEntryRepository warehouseEntryRepository = null;

	@GetMapping("/")
	public String internListedArticles(Model model) {

		List<UImodelArticles> totals = new ArrayList<UImodelArticles>();

		for (Article article : articleRepository.findAll()) {
			UImodelArticles tmp = new UImodelArticles();
			tmp.addListedArticle(article, warehouseEntryRepository.getArticleStock(article.id).orElse(0));
			totals.add(tmp);
		}

		model.addAttribute("ListedArticles", totals);
		return "intern/listedArticles/index";
	}

	@GetMapping("/{id}")
	public String internListedArticlesId(Model model, @PathVariable String id) {

		int articleid = Integer.parseInt(id);

		UImodelArticle total = new UImodelArticle();

		total.addArticle(articleRepository.findArticleById(articleid),
				warehouseEntryRepository.getArticleStock(articleid).orElse(0));

		model.addAttribute("ArticleID", total);

		return "intern/listedArticles/id";
	}

	@PostMapping("/{id}/saveChanges")
	public RedirectView saveChanges(
			@ModelAttribute UImodelArticle changedArticleTotal,
			@RequestParam("units-per-slot") String sWarehouseUnitsPerSlot,
			@RequestParam("price_netto") String sPrice_netto, 
			@RequestParam("reorderMaxPrice") String sReorderMaxPrice,
			@RequestParam("autobuy") String sShouldReorder, 
			@RequestParam("categories") String sCategories) {

		Article oldArticle = articleRepository.findArticleById(changedArticleTotal.id);

		// TODO img
		// TODO categories
		/*
		 * String separatedCategories[] = sCategories.split("\\r?\\n");
		 * 
		 * 
		 * for (int i = 0; i < separatedCategories.length; i++) {
		 * 
		 * oldArticle.categories.add(separatedCategories[i]);
		 * 
		 * }
		 */

		oldArticle.shouldReorder = (sShouldReorder.equals("true")) ? true : false; 
		oldArticle.reorderMaxPrice = (int) (Float.parseFloat(sReorderMaxPrice) * 100); 
		oldArticle.shopPricePerUnitNetCent = (int) (Float.parseFloat(sPrice_netto) * 100);
		oldArticle.warehouseUnitsPerSlot = Integer.parseInt(sWarehouseUnitsPerSlot);
		oldArticle.title = changedArticleTotal.title;
		oldArticle.description = changedArticleTotal.description;

		articleRepository.save(oldArticle); // save updated article
		return new RedirectView("../"); //return to overview page
	}

	
	public static class UImodelArticles {

		public String imgPath;

		public String title;

		public String price;

		public String price_netto;

		public String categorie;

		public int stock;

		public long offer_id;

		public long id;

		void addListedArticle(Article article, int stock) {
			this.imgPath = article.image.path;
			this.title = article.title;
			this.price_netto = String.format("%.2f", ((float) article.shopPricePerUnitNetCent / 100));
			this.price = String.format("%.2f", ((float) article.getPriceGross() / 100));
			this.categorie = article.getCategories();
			this.stock = stock;
			this.offer_id = article.related.id;
			this.id = article.id;
		}
	}

	public static class UImodelArticle {

		public String getImgPath() {
			return imgPath;
		}

		public void setImgPath(String imgPath) {
			this.imgPath = imgPath;
		}

		public String getTitle() {
			return title;
		}

		public void setTitle(String title) {
			this.title = title;
		}

		public String getPrice() {
			return price;
		}

		public void setPrice(String price) {
			this.price = price;
		}

		public String getPrice_netto() {
			return price_netto;
		}

		public void setPrice_netto(String price_netto) {
			this.price_netto = price_netto;
		}

		public String getReorderMaxPrice() {
			return reorderMaxPrice;
		}

		public void setReorderMaxPrice(String reorderMaxPrice) {
			this.reorderMaxPrice = reorderMaxPrice;
		}

		public String getCategorie() {
			return categorie;
		}

		public void setCategorie(String categorie) {
			this.categorie = categorie;
		}

		public int getStock() {
			return stock;
		}

		public void setStock(int stock) {
			this.stock = stock;
		}

		public long getOffer_id() {
			return offer_id;
		}

		public void setOffer_id(long offer_id) {
			this.offer_id = offer_id;
		}

		public long getId() {
			return id;
		}

		public void setId(long id) {
			this.id = id;
		}

		public boolean isShouldReorder() {
			return shouldReorder;
		}

		public void setShouldReorder(boolean shouldReorder) {
			this.shouldReorder = shouldReorder;
		}

		public String getWarehouseUnitsPerSlot() {
			return warehouseUnitsPerSlot;
		}

		public void setWarehouseUnitsPerSlot(String warehouseUnitsPerSlot) {
			this.warehouseUnitsPerSlot = warehouseUnitsPerSlot;
		}

		public String getDescription() {
			return description;
		}

		public void setDescription(String description) {
			this.description = description;
		}

		public String imgPath;
		public String title;
		public String price;
		public String price_netto;
		public String reorderMaxPrice;
		public String categorie;
		public int stock;
		public long offer_id;
		public long id;
		public boolean shouldReorder;
		public String warehouseUnitsPerSlot;
		public String description;

		void addArticle(Article article, int stock) {
			this.imgPath = article.image.path;
			this.title = article.title;
			this.price_netto = String.format("%.2f", ((float) article.shopPricePerUnitNetCent / 100));
			this.price = String.format("%.2f", ((float) article.getPriceGross() / 100));
			this.categorie = article.getCategories();
			this.stock = stock;
			this.offer_id = article.related.id;
			this.id = article.id;
			this.reorderMaxPrice = String.format("%.2f", ((float) article.reorderMaxPrice / 100));
			this.shouldReorder = article.shouldReorder;
			this.warehouseUnitsPerSlot = String.valueOf(article.warehouseUnitsPerSlot);
			this.description = article.description;
		}
	}

}
